@@ -25,7 +25,7 @@ class TestPostgres:
     def disconnect(self):
         self._conn.close()
 
-    def create(self):
+    def recreate(self):
         self.drop()
         self._conn.cursor().execute(f'CREATE DATABASE "{self._db_name}"')
 
@@ -38,7 +38,7 @@ class TestPostgres:
 
     def __enter__(self):
         self.connect()
-        self.create()
+        self.recreate()
 
         return self
 
